@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@
 namespace Bufhandle_vector {
 
 int first_;				// index of first element
+int last_visited_;			// absolute index for last_visited
 std::vector< Buffer_handle > data;
 
 
@@ -40,7 +41,7 @@ std::vector< Buffer_handle > data;
 //
 void emergency_save()
   {
-  if( handles() == 0 ) return;
+  if( !handles() ) return;
   int i = 0;
   for( ; i < handles(); ++i )
     if( data[i].buffer().modified() ) break;
@@ -67,11 +68,11 @@ void emergency_save()
 } // end namespace Bufhandle_vector
 
 
-void Bufhandle_vector::init() throw()
-  { first_ = 0; std::atexit( emergency_save ); }
+void Bufhandle_vector::init()
+  { first_ = 0; last_visited_ = 0; std::atexit( emergency_save ); }
 
 
-void Bufhandle_vector::save_all_named() throw()
+void Bufhandle_vector::save_all_named()
   {
   int count = 0;
   bool done = true;
@@ -93,7 +94,7 @@ void Bufhandle_vector::save_all_named() throw()
   }
 
 
-void Bufhandle_vector::show_status() throw()
+void Bufhandle_vector::show_status()
   {
   int mcount = 0, ucount = 0;
 
@@ -112,22 +113,22 @@ void Bufhandle_vector::show_status() throw()
   }
 
 
-int Bufhandle_vector::absolute_index( const int i ) throw()
+int Bufhandle_vector::absolute_index( const int i )
   { return ( i + first_ ) % handles(); }
 
 
-int Bufhandle_vector::circular_index( const int ai ) throw()
+int Bufhandle_vector::circular_index( const int ai )
   { return ( ai + handles() - first_ ) % handles(); }
 
 
-Buffer_handle & Bufhandle_vector::handle( const int i ) throw()
+Buffer_handle & Bufhandle_vector::handle( const int i )
   { return data[absolute_index(i)]; }
 
 
-int Bufhandle_vector::handles() throw() { return data.size(); }
+int Bufhandle_vector::handles() { return data.size(); }
 
 
-int Bufhandle_vector::handles( const Buffer & buffer ) throw()
+int Bufhandle_vector::handles( const Buffer & buffer )
   {
   int c = 0;
   for( int i = 0; i < handles(); ++i ) if( &buffer == &data[i].buffer() ) ++c;
@@ -135,30 +136,29 @@ int Bufhandle_vector::handles( const Buffer & buffer ) throw()
   }
 
 
-int Bufhandle_vector::last_visited( const int i ) throw()
+int Bufhandle_vector::last_visited( const int i )
   {
-  static int ai = 0;
-  const int ci = circular_index( ai );
-  ai = absolute_index( i );
+  const int ci = circular_index( last_visited_ );
+  last_visited_ = absolute_index( i );
   return ci;
   }
 
 
-void Bufhandle_vector::next() throw()
+void Bufhandle_vector::next()
   { ++first_; first_ %= handles(); }
 
 
-void Bufhandle_vector::prev() throw()
+void Bufhandle_vector::prev()
   { --first_; first_ += handles(); first_ %= handles(); }
 
 
-void Bufhandle_vector::set_first( const int ai ) throw()
+void Bufhandle_vector::set_first( const int ai )
   { first_ = ai % handles(); }
 
 
 int Bufhandle_vector::find_or_add_handle( const Buffer::Options & opts,
                                           const std::string * const namep,
-                                          int i, const int line )
+                                          int i, const int line, const int col )
   {
   if( namep && namep->size() )
     for( int j = 0; j < handles(); ++j )
@@ -172,18 +172,21 @@ int Bufhandle_vector::find_or_add_handle( const Buffer::Options & opts,
   else
     {
     i = absolute_index( i );
-    if( i == 0 ) i = handles(); else if( i <= first_ ) ++first_;
+    if( i == 0 ) i = handles();
+    else { if( i <= first_ ) ++first_;
+           if( i <= last_visited_ ) ++last_visited_; }
     }
-  data.insert( data.begin() + i, Buffer_handle( *bufp, line ) );
+  data.insert( data.begin() + i, Buffer_handle( *bufp, line, col ) );
   return circular_index( i );
   }
 
 
      // Add empty buffer if no files given or stdin is not a tty
-void Bufhandle_vector::add_handle_if_pending_input_or_empty( const int line )
+void Bufhandle_vector::add_handle_if_pending_input_or_empty( const int line,
+                                                             const int col )
   {
   if( !handles() || !isatty( fileno( stdin ) ) )
-    find_or_add_handle( RC::default_buffer_options(), 0, -1, line );
+    find_or_add_handle( RC::default_buffer_options(), 0, -1, line, col );
   }
 
 
@@ -191,11 +194,12 @@ void Bufhandle_vector::duplicate_handle( int i )
   {
   i = absolute_index( i );
   if( i < first_ ) ++first_;
+  if( i < last_visited_ ) ++last_visited_;
   data.insert( data.begin() + i + 1, data[i] );
   }
 
 
-bool Bufhandle_vector::delete_handle( int i ) throw()
+bool Bufhandle_vector::delete_handle( int i )
   {
   if( i < 0 || i >= handles() ) return false;
   else i = absolute_index( i );
@@ -210,5 +214,7 @@ bool Bufhandle_vector::delete_handle( int i ) throw()
     }
   data.erase( data.begin() + i );
   if( i <= first_ && handles() ) prev();
+  if( i <= last_visited_ && handles() )
+    { --last_visited_; last_visited_ += handles(); last_visited_ %= handles(); }
   return true;
   }
