@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -16,23 +16,22 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 class Buffer_handle
   {
   Buffer * bufferp_;	// handled buffer
 
 public:
   Point top_left;	// buffer coordinates of window top-left corner
-  Point cursor;		// buffer coordinates of window cursor
-  Point pointer;	// current buffer character
+  Point cursor;		// buffer virtual coordinates of window cursor
+  Point pointer;	// current buffer character (index in buffer[])
   Point pcursor;	// buffer coordinates of current buffer character
 
-  Buffer_handle( Buffer & buffer, const int line = 0 ) throw()
-    : bufferp_( &buffer ), top_left( line, 0 ), cursor( line, 0 ),
-      pointer( line, 0 ), pcursor( line, 0 ) {}
+  Buffer_handle( Buffer & buffer, const int line = 0, const int col = 0 )
+    : bufferp_( &buffer ), top_left( 0, 0 ), cursor( line, col ),
+      pointer( cursor ), pcursor( cursor ) {}
 
-  Buffer & buffer() throw() { return *bufferp_; }
-  const Buffer & buffer() const throw() { return *bufferp_; }
+  Buffer & buffer() { return *bufferp_; }
+  const Buffer & buffer() const { return *bufferp_; }
   };
 
 
@@ -42,25 +41,25 @@ public:
 //
 namespace Bufhandle_vector {
 
-void init() throw();
-void save_all_named() throw();
-void show_status() throw();
+void init();
+void save_all_named();
+void show_status();
 
-int absolute_index( const int i ) throw();
-int circular_index( const int ai ) throw();
-Buffer_handle & handle( const int i ) throw();
-int handles() throw();
-int handles( const Buffer & buffer ) throw();
-int last_visited( const int i ) throw();
-void next() throw();
-void prev() throw();
-void set_first( const int ai ) throw();
+int absolute_index( const int i );
+int circular_index( const int ai );
+Buffer_handle & handle( const int i );
+int handles();
+int handles( const Buffer & buffer );
+int last_visited( const int i );
+void next();
+void prev();
+void set_first( const int ai );
 
 int find_or_add_handle( const Buffer::Options & opts,
                         const std::string * const namep = 0,
-                        int i = -1, const int line = 0 );
-void add_handle_if_pending_input_or_empty( const int line );
+                        int i = -1, const int line = 0, const int col = 0 );
+void add_handle_if_pending_input_or_empty( const int line, const int col );
 void duplicate_handle( int i );
-bool delete_handle( int i ) throw();
+bool delete_handle( int i );
 
 } // end namespace Bufhandle_vector
