@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -18,16 +18,16 @@
 
 namespace Encoding {
 
-void base64_encode( const std::string & in, std::string & out ) throw();
+void base64_encode( const std::string & in, std::string & out );
 
-bool base64_decode( const std::string & in, std::string & out ) throw();
+bool base64_decode( const std::string & in, std::string & out );
 
-bool quoted_printable_decode( const std::string & in, std::string & out ) throw();
+bool quoted_printable_decode( const std::string & in, std::string & out );
 
-unsigned char rot13( const unsigned char ch ) throw();
+unsigned char rot13( const unsigned char ch );
 
-unsigned char rot47( const unsigned char ch ) throw();
+unsigned char rot47( const unsigned char ch );
 
-bool utf8_decode( const std::string & in, std::string & out ) throw();
+bool utf8_decode( const std::string & in, std::string & out );
 
 } // end namespace Encoding
