@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -30,65 +30,65 @@
 
 namespace Menu {
 
-const int columns = 3;
+enum { columns = 3 };
 int current;		// current highlighted entry in menu
 int entries;		// number of entries in menu
 int height_;		// height in lines of menu
 
 
-const char * autoindent_status( const Buffer & buffer ) throw()
+const char * autoindent_status( const Buffer & buffer )
   { return buffer.options.auto_indent ? "ON" : "OFF"; }
 
-bool autoindent_change( Buffer & buffer ) throw()
+bool autoindent_change( Buffer & buffer )
   { buffer.options.auto_indent = !buffer.options.auto_indent; return true; }
 
 
-const char * backup_status( const Buffer & ) throw()
+const char * backup_status( const Buffer & )
   { return RC::editor_options().backup ? "ON" : "OFF"; }
 
-bool backup_change( Buffer & ) throw()
+bool backup_change( Buffer & )
   { RC::editor_options().backup = !RC::editor_options().backup; return true; }
 
 /*
-const char * beep_status( const Buffer & ) throw()
+const char * beep_status( const Buffer & )
   { return RC::editor_options().beep ? "ON" : "OFF"; }
 
-bool beep_change( Buffer & ) throw()
+bool beep_change( Buffer & )
   { RC::editor_options().beep = !RC::editor_options().beep; return true; }
 */
 
-const char * crlf_status( const Buffer & buffer ) throw()
+const char * crlf_status( const Buffer & buffer )
   { return buffer.crlf ? "ON" : "OFF"; }
 
-bool crlf_change( Buffer & buffer ) throw()
+bool crlf_change( Buffer & buffer )
   { buffer.crlf = !buffer.crlf; return true; }
 
 
-const char * exit_ask_status( const Buffer & ) throw()
+const char * exit_ask_status( const Buffer & )
   { return RC::editor_options().exit_ask ? "ON" : "OFF"; }
 
-bool exit_ask_change( Buffer & ) throw()
+bool exit_ask_change( Buffer & )
   { RC::editor_options().exit_ask = !RC::editor_options().exit_ask; return true; }
 
 
-const char * smart_home_status( const Buffer & ) throw()
+const char * smart_home_status( const Buffer & )
   { return RC::editor_options().smart_home ? "ON" : "OFF"; }
 
-bool smart_home_change( Buffer & ) throw()
+bool smart_home_change( Buffer & )
   { RC::editor_options().smart_home = !RC::editor_options().smart_home; return true; }
 
 
-const char * ignore_case_status( const Buffer & ) throw()
+const char * ignore_case_status( const Buffer & )
   { return RC::editor_options().ignore_case ? "ON" : "OFF"; }
 
-bool ignore_case_change( Buffer & ) throw()
+bool ignore_case_change( Buffer & )
   { RC::editor_options().ignore_case = !RC::editor_options().ignore_case; return true; }
 
 
-const char * indent_step_status( const Buffer & ) throw()
+const char * indent_step_status( const Buffer & )
   {
   static char buf[8];
-  snprintf( buf, sizeof buf, "%d", RC::editor_options().indent_step );
+  snprintf( buf, sizeof buf, "%d", RC::editor_options().indent_step() );
   return buf;
   }
 
@@ -101,17 +101,17 @@ bool indent_step_change( Buffer & )
                           history ) <= 0 ) return false;
   const std::string & s = history.back();
   int i;
-  if( !RC::parse_int( s, i ) || i < 1 || i >= Screen::width() )
-    { Screen::show_message( "Value out of range" ); history.pop_back();
-    return false; }
-  RC::editor_options().indent_step = i; return true;
+  if( RC::parse_int( s, i ) && RC::editor_options().set_indent_step( i ) )
+    return true;
+  Screen::show_message( "Value out of range" ); history.pop_back();
+  return false;
   }
 
 
-const char * keep_lines_status( const Buffer & ) throw()
+const char * keep_lines_status( const Buffer & )
   {
   static char buf[8];
-  snprintf( buf, sizeof buf, "%d", RC::editor_options().keep_lines );
+  snprintf( buf, sizeof buf, "%d", RC::editor_options().keep_lines() );
   return buf;
   }
 
@@ -124,14 +124,14 @@ bool keep_lines_change( Buffer & )
                           history ) <= 0 ) return false;
   const std::string & s = history.back();
   int i;
-  if( !RC::parse_int( s, i ) || i < -1 || i >= Screen::height() )
-    { Screen::show_message( "Value out of range" ); history.pop_back();
-    return false; }
-  RC::editor_options().keep_lines = i; return true;
+  if( RC::parse_int( s, i ) && RC::editor_options().set_keep_lines( i ) )
+    return true;
+  Screen::show_message( "Value out of range" ); history.pop_back();
+  return false;
   }
 
 
-const char * lmargin_status( const Buffer & buffer ) throw()
+const char * lmargin_status( const Buffer & buffer )
   {
   static char buf[8];
   snprintf( buf, sizeof buf, "%d", buffer.options.lmargin() + 1 );
@@ -154,10 +154,10 @@ bool lmargin_change( Buffer & buffer )
   }
 
 
-const char * max_windows_status( const Buffer & ) throw()
+const char * max_windows_status( const Buffer & )
   {
   static char buf[8];
-  snprintf( buf, sizeof buf, "%d", RC::editor_options().max_windows );
+  snprintf( buf, sizeof buf, "%d", RC::editor_options().max_windows() );
   return buf;
   }
 
@@ -170,21 +170,21 @@ bool max_windows_change( Buffer & )
                           history ) <= 0 ) return false;
   const std::string & s = history.back();
   int i;
-  if( !RC::parse_int( s, i ) || i < 0 || i > Screen::max_windows() )
-    { Screen::show_message( "Value out of range" ); history.pop_back();
-    return false; }
-  RC::editor_options().max_windows = i; return true;
+  if( RC::parse_int( s, i ) && RC::editor_options().set_max_windows( i ) )
+    return true;
+  Screen::show_message( "Value out of range" ); history.pop_back();
+  return false;
   }
 
 
-const char * read_only_status( const Buffer & buffer ) throw()
+const char * read_only_status( const Buffer & buffer )
   { return buffer.options.read_only ? "ON" : "OFF"; }
 
-bool read_only_change( Buffer & buffer ) throw()
+bool read_only_change( Buffer & buffer )
   { buffer.options.read_only = !buffer.options.read_only; return true; }
 
 
-const char * rmargin_status( const Buffer & buffer ) throw()
+const char * rmargin_status( const Buffer & buffer )
   {
   static char buf[8];
   snprintf( buf, sizeof buf, "%d", buffer.options.rmargin() + 1 );
@@ -207,31 +207,31 @@ bool rmargin_change( Buffer & buffer )
   }
 
 
-const char * search_wrap_status( const Buffer & ) throw()
+const char * search_wrap_status( const Buffer & )
   { return RC::editor_options().search_wrap ? "ON" : "OFF"; }
 
-bool search_wrap_change( Buffer & ) throw()
+bool search_wrap_change( Buffer & )
   { RC::editor_options().search_wrap = !RC::editor_options().search_wrap; return true; }
 
 
-const char * auto_unmark_status( const Buffer & ) throw()
+const char * auto_unmark_status( const Buffer & )
   { return RC::editor_options().auto_unmark ? "ON" : "OFF"; }
 
-bool auto_unmark_change( Buffer & ) throw()
+bool auto_unmark_change( Buffer & )
   { RC::editor_options().auto_unmark = !RC::editor_options().auto_unmark; return true; }
 
 
-const char * word_wrap_status( const Buffer & buffer ) throw()
+const char * word_wrap_status( const Buffer & buffer )
   { return buffer.options.word_wrap ? "ON" : "OFF"; }
 
-bool word_wrap_change( Buffer & buffer ) throw()
+bool word_wrap_change( Buffer & buffer )
   { buffer.options.word_wrap = !buffer.options.word_wrap; return true; }
 
 
-const char * rectangle_mode_status( const Buffer & ) throw()
+const char * rectangle_mode_status( const Buffer & )
   { return RC::editor_options().rectangle_mode ? "ON" : "OFF"; }
 
-bool rectangle_mode_change( Buffer & ) throw()
+bool rectangle_mode_change( Buffer & )
   {
   RC::editor_options().rectangle_mode = !RC::editor_options().rectangle_mode;
   Screen::show_status_lines();
@@ -244,7 +244,7 @@ struct Entry
   {
   char ch;			// Menu letter
   const char * const str;	// Menu string
-  const char * (*status)( const Buffer & buffer ) throw();
+  const char * (*status)( const Buffer & buffer );
   bool (*change)( Buffer & buffer );
   };
 
@@ -272,7 +272,7 @@ Entry table[] = {
 
 struct Init_menu
   {
-  Init_menu() throw()
+  Init_menu()
     {
     current = 0;
     for( entries = 0; table[entries].ch; ++entries ) ;
@@ -281,7 +281,7 @@ struct Init_menu
   } dummy;
 
 
-bool set_current( int key ) throw()
+bool set_current( int key )
   {
   if( key >= 0 && key < 128 )
     {
@@ -294,7 +294,7 @@ bool set_current( int key ) throw()
   }
 
 
-void show( const Buffer & buffer, Point & cursor ) throw()
+void show( const Buffer & buffer, Point & cursor )
   {
   for( int line = 0; line < height_; ++line )
     {
@@ -307,7 +307,8 @@ void show( const Buffer & buffer, Point & cursor ) throw()
       s += table[i].ch; s += ' '; s += table[i].str;
       if( table[i].status )
         { const char * const st = table[i].status( buffer ); if( st ) s += st; }
-      unsigned int col = ( ( ( i % columns ) + 1 ) * Screen::width() ) / columns + offset;
+      const unsigned col = offset +
+            ( ( ( ( i % columns ) + 1 ) * Screen::width() ) / columns );
       while( s.size() < col ) s += ' ';
       if( i == current ) { s += "@i"; offset += 2; }
       }
