@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -18,28 +18,46 @@
 
 namespace RC {
 
-struct Options
+class Options
   {
-  int indent_step, keep_lines, max_windows;
+  int indent_step_, keep_lines_, max_windows_;
+public:
   bool auto_unmark, backup, /*beep,*/ exit_ask, ignore_case;
   bool orphan_extra, rectangle_mode, search_wrap, show_code, smart_home;
 
-  Options() throw()
-    : indent_step( 2 ), keep_lines( -1 ), max_windows( 0 ),
+  Options()
+    : indent_step_( 2 ), keep_lines_( -1 ), max_windows_( 0 ),
     auto_unmark( false ), backup( true ), /*beep( false ),*/ exit_ask( false ),
     ignore_case( false ), orphan_extra( false ), rectangle_mode( false ),
     search_wrap( false ), show_code( false ), smart_home( true ) {}
 
-  void reset() throw() { *this = Options(); }
+  int indent_step() const { return indent_step_; }
+  int keep_lines() const { return keep_lines_; }
+  int max_windows() const { return max_windows_; }
+  bool set_indent_step( const int n )
+    { if( n < 1 || n > 99 ) { return false; } indent_step_ = n; return true; }
+  bool set_keep_lines( const int n )
+    { if( n < -1 || n > 99 ) { return false; } keep_lines_ = n; return true; }
+  bool set_max_windows( const int n )
+    { if( n < 0 || n > 99 ) { return false; } max_windows_ = n; return true; }
+
+  void reset() { *this = Options(); }
   };
 
 
-Options & editor_options() throw();		// Global editor options
-const Buffer::Options & default_buffer_options() throw();
+Options & editor_options();			// Global editor options
+const Buffer::Options & default_buffer_options();
 
-void apply_regex_options( Buffer & buffer ) throw();
+void apply_regex_options( Buffer & buffer );
 
-bool parse_int( const std::string & s, int & result ) throw();
+     // Returns true if first non whitespace character is '+' or '-'.
+bool issigned( const std::string & s );
+
+    // Returns the number of chars read, or 0 if error.
+int parse_int( const std::string & s, int & result );
+
+    // Returns the number of chars read, or 0 if error.
+int parse_relative_int( const std::string & s, int & result );
 
     // Returns 0 for success, 1 for file not found, 2 for syntax error.
 int process_rcfile( const std::string & name );
@@ -49,11 +67,11 @@ int process_options();
 
 int read_options( const int argc, const char * const argv[] );
 
-void reset() throw();
+void reset();
 
     // Defined in main.cc
-const std::string & home_directory() throw();
+const std::string & home_directory();
 void show_error( const char * const msg, const int errcode = 0,
-                 const bool help = false ) throw();
+                 const bool help = false );
 
 } // end namespace RC
