@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -45,7 +45,7 @@ struct Lines_and_cursor
   std::vector< chtype > buf;
   Point cursor;
 
-  Lines_and_cursor( const int ln, const int lns ) throw()
+  Lines_and_cursor( const int ln, const int lns )
     : line( ln ), lines( lns ) {}
   };
 
@@ -55,14 +55,15 @@ int height_, width_;
 int clock_limit;		//   0: disable clock
 				//   1: showing help
 				// > 1: first line used by menu
-char clock_string_[6] = " 0:00";
+enum { clock_string_size = 6 };
+char clock_string_[clock_string_size+1] = " 0:00 ";
 
 std::vector< Lines_and_cursor > lines_and_cursor_vector;
 
 
-void dummy_endwin() throw() { endwin(); }
+void dummy_endwin() { endwin(); }
 
-void initialize_ncurses() throw()
+void initialize_ncurses()
   {
   std::atexit( dummy_endwin );
   initscr();			// initializes curses data structures
@@ -75,12 +76,12 @@ void initialize_ncurses() throw()
   }
 
 
-void rep_addch( int n, const chtype ch ) throw()
+void rep_addch( int n, const chtype ch )
   { for( ; n > 0; --n ) waddch( stdscr, ch ); }
 
 
 void out_raw_string( const int line, const int col, const std::string & s,
-                     const int len, int pos = 0, const chtype atr = A_NORMAL ) throw()
+                     const int len, int pos = 0, const chtype atr = A_NORMAL )
   {
   wmove( stdscr, line, col );
   int x = col, limit = std::min( x + len, width_ );
@@ -99,7 +100,7 @@ void out_raw_string( const int line, const int col, const std::string & s,
 // '@@' shows a '@'
 //
 void out_string( const int line, const int col, const std::string & s,
-                 const int len, int pos = 0 ) throw()
+                 const int len, int pos = 0 )
   {
   wmove( stdscr, line, col );
   int x = col, limit = std::min( x + len, width_ );
@@ -121,9 +122,9 @@ void out_string( const int line, const int col, const std::string & s,
   }
 
 
-void remove_duplicates( std::vector< std::string > & history ) throw()
+void remove_duplicates( std::vector< std::string > & history )
   {
-  for( unsigned int i = 0; i + 1 < history.size(); )
+  for( unsigned i = 0; i + 1 < history.size(); )
     {
     if( history[i].size() && history[i] != history.back() ) ++i;
     else history.erase( history.begin() + i );
@@ -131,7 +132,7 @@ void remove_duplicates( std::vector< std::string > & history ) throw()
   }
 
 
-void alt_key_loop( int key ) throw()
+void alt_key_loop( int key )
   {
   Window & w = Window_vector::curwin();
   w.show_status_line( ISO_8859::control_name( key ) );
@@ -147,14 +148,15 @@ void alt_key_loop( int key ) throw()
     case 'D': w.center_cursor(); break;
     case 'F': w.goto_matching_delimiter(); break;
     case 'G': w.goto_matching_delimiter( false ); break;
+    case 'I': w.show_character_info(); break;
     case 'K': w.goto_end_of_block(); break;
     case 'L': w.goto_line(); break;
     case 'O': w.goto_offset(); break;
     case 'S': w.scroll_horizontal( 8 ); break;
     case 'U': w.goto_bof(); break;
     case 'V': w.goto_eof(); break;
-    case 'W': w.scroll_page( false ); break;
-    case 'Z': w.scroll_page( true ); break;
+    case 'W': w.move_page( false, true ); break;
+    case 'Z': w.move_page( true, true ); break;
     }
   }
 
@@ -233,7 +235,7 @@ int control_q_loop( int key, const char ** const msgp )
   }
 
 
-void control_s_loop( int key, const std::string & version_msg ) throw()
+void control_s_loop( int key, const std::string & version_msg )
   {
   Window & w = Window_vector::curwin();
   w.show_status_line( ISO_8859::control_name( key ) );
@@ -242,10 +244,15 @@ void control_s_loop( int key, const std::string & version_msg ) throw()
   key = ISO_8859::decontrolize( key );
   switch( key )
     {
+    case KEY_F(2):
+    case KEY_F(4):
+    case KEY_F(8): w.show_multichar_value( key - KEY_F(0), true ); break;
+    case '2':
+    case '4':
+    case '8': w.show_multichar_value( key - '0', false ); break;
     case 'C': RC::editor_options().show_code = !RC::editor_options().show_code;
               show_status_lines(); break;
     case 'G': Bufhandle_vector::show_status(); break;
-    case 'I': w.show_character_info(); break;
     case 'V': show_message( version_msg ); break;
     }
   }
@@ -275,7 +282,7 @@ void user_data( const std::string & s, const int base )
       if( base == 8 &&  !ISO_8859::isodigit( s[i] ) )
         { show_message( "Invalid octal data" ); return; }
       int carry = s[i] - '0';
-      for( unsigned int j = 0; j < buf.size(); ++j )
+      for( unsigned j = 0; j < buf.size(); ++j )
         {
         buf[j] = ( buf[j] * base ) + carry;
         carry = buf[j] / 256;
@@ -285,10 +292,10 @@ void user_data( const std::string & s, const int base )
       }
   if( !buf.size() ) buf.push_back( 0 );
   if( big_endian )
-    for( unsigned int i = buf.size(); i > 0; --i )
+    for( unsigned i = buf.size(); i > 0; --i )
       Window_vector::add_char( buf[i-1], true );
   else
-    for( unsigned int i = 0; i < buf.size(); ++i )
+    for( unsigned i = 0; i < buf.size(); ++i )
       Window_vector::add_char( buf[i], true );
   }
 
@@ -333,8 +340,8 @@ void user_control_char( const int abort_key )
   }
 
 
-// `read_key' implements a buffer to speed up pastes, because `wgetch'
-// always calls `wrefresh'. `read_key' also converts '\r' to '\n'.
+// 'read_key' implements a buffer to speed up pastes, because 'wgetch'
+// always calls 'wrefresh'. 'read_key' also converts '\r' to '\n'.
 //
 int read_key( const bool wait, const bool get_key )
   {
@@ -386,46 +393,48 @@ bool Screen::init()
   }
 
 
-int Screen::height() throw() { return height_; }
+int Screen::height() { return height_; }
 
-int Screen::width() throw() { return width_; }
+int Screen::width() { return width_; }
 
-int Screen::max_windows() throw() { return height_ / Window::min_height; }
+int Screen::max_windows() { return height_ / Window::min_height; }
 
 
-char * Screen::line_buf( int * const sizep ) throw()
+char * Screen::line_buf( int * const sizep )
   { *sizep = line_buf_size; return line_buf_; }
 
 
-//void Screen::beep() throw() { ::beep(); wrefresh( stdscr ); }
+//void Screen::beep() { ::beep(); wrefresh( stdscr ); }
 
 
-const char * Screen::clock_string() throw() { return clock_string_; }
+const char * Screen::clock_string() { return clock_string_; }
 
 
 // updates the clock
-extern "C" void Screen::clock_handler( int sig ) throw()
+extern "C" void Screen::clock_handler( int sig )
   {
   const time_t tt = std::time( 0 );
   const std::tm * const t = std::localtime( &tt );
   if( t )
     {
     int h = t->tm_hour % 12; if( h == 0 ) h = 12;
-    clock_string_[0] = ( h >= 10 ) ? '0' + ( h / 10 ) : ' ';
+    clock_string_[0] = ( ( h < 10 ) ? ' ' : '1' );
     clock_string_[1] = '0' + ( h % 10 );
     clock_string_[2] = (clock_string_[2] != ':') ? ':' : ' ';
     clock_string_[3] = '0' + ( t->tm_min / 10 );
     clock_string_[4] = '0' + ( t->tm_min % 10 );
+    clock_string_[5] = ( ( t->tm_hour < 12 ) ? ' ' : '.' );
     if( sig )
       {
       Point old_cursor; save_cursor( old_cursor );
       if( clock_limit == 1 )
-        out_raw_string( 0, 60, clock_string_, 5, 0, A_REVERSE );
+        out_raw_string( 0, 60, clock_string_, clock_string_size, 0, A_REVERSE );
       else for( int i = 0; i < Window_vector::windows(); ++i )
         {
         const Point cursor = Window_vector::window( i ).clock_position();
         if( cursor.line >= clock_limit ) break;
-        out_raw_string( cursor.line, cursor.col, clock_string_, 5, 0, A_REVERSE );
+        out_raw_string( cursor.line, cursor.col, clock_string_,
+                        clock_string_size, 0, A_REVERSE );
         }
       wmove( stdscr, old_cursor.line, old_cursor.col );
       wrefresh( stdscr ); alarm( 1 );
@@ -476,12 +485,14 @@ int Screen::get_string( const std::string & prompt,
   remove_duplicates( history );
   std::string s( prompt );
   s += history.back();
-  unsigned int scol = s.size(), idx = history.size() - 1;
+  int scol = s.size();
+  int idx = history.size() - 1;
   int key = 0;
   bool modified = false;
   while( key >= 0 )
     {
-    int pos = scol; pos -= ( width_ - 1 ); if( pos < 0 ) pos = 0;
+    const int ahead = std::max( 1, std::min( 8, (int)s.size() + 1 - scol ) );
+    const int pos = std::max( 0, scol + ahead - width_ );
     out_raw_string( line, 0, s, width_, pos );
     wmove( stdscr, line, scol - pos );
     do key = wait_kbhit( line ); while( key < 0 );
@@ -501,6 +512,7 @@ int Screen::get_string( const std::string & prompt,
                      name.erase( name.size() - 1 );
                    s.insert( prompt.size(), name );
                    }
+                 else { s.insert( scol, "\\t" ); scol += 2; modified = true; }
                  break;
       case '\n': {
                  std::string name( s, prompt.size(), s.size() );
@@ -523,14 +535,14 @@ int Screen::get_string( const std::string & prompt,
                         }
                       break;
       case 127          :					// delete
-      case KEY_BACKSPACE: if( scol > prompt.size() )
+      case KEY_BACKSPACE: if( scol > (int)prompt.size() )
                             { s.erase( --scol, 1 ); modified = true; } break;
-      case KEY_DC   : if( scol < s.size() )
+      case KEY_DC   : if( scol < (int)s.size() )
                         { s.erase( scol, 1 ); modified = true; } break;
       case KEY_HOME : scol = prompt.size(); break;
       case KEY_END  : scol = s.size(); break;
-      case KEY_LEFT : if( scol > prompt.size() ) { --scol; } break;
-      case KEY_RIGHT: if( scol < s.size() ) { ++scol; } break;
+      case KEY_LEFT : if( scol > (int)prompt.size() ) { --scol; } break;
+      case KEY_RIGHT: if( scol < (int)s.size() ) { ++scol; } break;
       case 25       : if( s.size() > prompt.size() )		// ^Y
                         { s.resize( prompt.size() ); scol = s.size();
                           modified = true; }		// fall through
@@ -542,14 +554,14 @@ int Screen::get_string( const std::string & prompt,
           modified = false;
           if( s.size() > prompt.size() )
             history[idx].assign( s, prompt.size(), s.size() );
-          else if( idx == history.size() - 1 ) history[idx].clear();
+          else if( idx == (int)history.size() - 1 ) history[idx].clear();
           else history.erase( history.begin() + idx );
           }
         if( key == KEY_PPAGE ) idx = 0; else --idx;
         s.erase( prompt.size(), s.size() ); s += history[idx]; scol = s.size();
         } break;
       case KEY_NPAGE:
-      case KEY_DOWN : if( idx + 1 < history.size() )
+      case KEY_DOWN : if( idx + 1 < (int)history.size() )
         {
         if( modified )
           {
@@ -577,11 +589,11 @@ int Screen::get_string( const std::string & prompt,
   }
 
 
-void Screen::move_to( const Point & cursor ) throw()
+void Screen::move_to( const Point & cursor )
   { wmove( stdscr, cursor.line, cursor.col ); }
 
 
-void Screen::save_cursor( Point & cursor ) throw()
+void Screen::save_cursor( Point & cursor )
   { getyx( stdscr, cursor.line, cursor.col ); }
 
 
@@ -597,7 +609,7 @@ void Screen::save_lines_and_cursor( const int line, const int lines )
   }
 
 
-void Screen::restore_lines_and_cursor() throw()
+void Screen::restore_lines_and_cursor()
   {
   const Lines_and_cursor & lc = lines_and_cursor_vector.back();
 
@@ -609,13 +621,13 @@ void Screen::restore_lines_and_cursor() throw()
   }
 
 
-void Screen::out_buffer_line( const Buffer & buffer, Point c, const int line ) throw()
+void Screen::out_buffer_line( const Buffer & buffer, Point c, const int line )
   {
   wmove( stdscr, line, 0 );
   if( c.line < 0 || c.line >= buffer.lines() )
     { rep_addch( width_, ' ' ); return; }
   Point pc, p = buffer.to_pointer( c, pc );
-  if( pc.col < c.col ) pc.col = c.col;		// landed in a tab
+//  if( pc.col < c.col ) pc.col = c.col;		// landed in a tab
 
   for( int i = 0; i < width_; ++i, ++c.col, ++p.col )
     {
@@ -638,7 +650,7 @@ void Screen::out_buffer_line( const Buffer & buffer, Point c, const int line ) t
 
 
 bool Screen::out_line( const std::string & s, const int line, const bool shift,
-                       const char mode ) throw()
+                       const char mode )
   {
   if( line < 0 || line >= height_ ) return false;
   int pos = s.size(); pos -= ( width_ - 1 );
@@ -657,7 +669,7 @@ bool Screen::out_line( const std::string & s, const int line, const bool shift,
 
 
 bool Screen::out_menu_line( const std::string & s, const int line,
-                            const int hbegin, const int hend ) throw()
+                            const int hbegin, const int hend )
   {
   if( line < 0 || line >= height_ ) return false;
   if( hbegin >= 0 && hbegin < hend && hend <= (int)s.size() )
@@ -674,7 +686,7 @@ bool Screen::out_menu_line( const std::string & s, const int line,
   }
 
 
-void Screen::repaint( const Buffer * const bufp ) throw()
+void Screen::repaint( const Buffer * const bufp )
   {
   for( int i = 0; i < Window_vector::windows(); ++i )
     {
@@ -705,7 +717,7 @@ int Screen::show_message( const std::string & s, const bool get_key,
   }
 
 
-void Screen::show_status_lines( const Buffer * const bufp ) throw()
+void Screen::show_status_lines( const Buffer * const bufp )
   {
   for( int i = 0; i < Window_vector::windows(); ++i )
     if( !bufp || bufp == &Window_vector::window( i ).buffer() )
@@ -713,7 +725,7 @@ void Screen::show_status_lines( const Buffer * const bufp ) throw()
   }
 
 
-Screen::Keys Screen::convert_key( const int key ) throw()
+Screen::Keys Screen::convert_key( const int key )
   {
   switch( key )
     {
@@ -730,7 +742,14 @@ Screen::Keys Screen::convert_key( const int key ) throw()
   }
 
 
-int Screen::user_loop( const std::string & version_msg ) throw()
+int Screen::function_key( const int key )
+  {
+  if( key >= KEY_F(1) && key <= KEY_F(12) ) return ( key - KEY_F(0) );
+  return -1;
+  }
+
+
+int Screen::user_loop( const std::string & version_msg )
   {
   show_message( version_msg );
   int retval = -1;
